==> tine20-allinone_2019.12.5.tar.bz2: Tasks/js/Tasks-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: bg\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Задачa"
 ,"Задачи"

]
, "Percent"
: "Процент"

, "Completed"
: "Завършен"

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: ""

, "Priority"
: "Приоритет"

, "Status, Status"
: [
  ""
 ,""

]
, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "Общо"

, "Due date"
: "Краен срок"

, "Add Responsible ..."
: ""

, "Notes"
: "Бележки"

, "Enter description..."
: "Напиши описание"

, "Percentage"
: "Процент"

, "Tasks"
: "Задачи"

, "to do list, to do lists"
: [
  "списък със задачи"
 ,"списъка със задачи"

]
, "to do lists"
: "списъци със задачи"

, "Quick Search"
: ""

, "Due Date"
: "Краен срок"

, "Responsible"
: "Отговорник"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Създаден на"

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Наистина ли желаете да изтриете селектираната задача?"
 ,"Наистина ли желаете да изтриете селектираните задачи?"

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: "Добави задача"

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: "организира списък на задачи"

, "Create new shared tasks lists"
: "Състави нов списък на споделени задачи"

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "%s's personal tasks"
: "%s's лични задачи"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "Задачa"

, "Status"
: ""

, "to do list"
: "списък със задачи"

, "Do you really want to delete the selected task?"
: "Наистина ли желаете да изтриете селектираната задача?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: "Общо"

, "Due date"
: "Краен срок"

, "Priority"
: "Приоритет"

, "Organizer"
: ""

, "Add Responsible ..."
: ""

, "Notes"
: "Бележки"

, "Enter description..."
: "Напиши описание"

, "Percentage"
: "Процент"

, "Status, Status"
: [
  ""
 ,""

]
, "Completed"
: "Завършен"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Наистина ли желаете да изтриете селектираната задача?"
 ,"Наистина ли желаете да изтриете селектираните задачи?"

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: "Добави задача"

, "Due Date"
: "Краен срок"

, "Percent"
: "Процент"

, "Responsible"
: "Отговорник"

, "Task, Tasks"
: [
  "Задачa"
 ,"Задачи"

]
, "Tasks"
: "Задачи"

, "to do list, to do lists"
: [
  "списък със задачи"
 ,"списъка със задачи"

]
, "to do lists"
: "списъци със задачи"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Създаден на"

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: "%s's лични задачи"

, "GENDER_Task"
: ""

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: "организира списък на задачи"

, "Create new shared tasks lists"
: "Състави нов списък на споделени задачи"

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "Status"
: ""

, "Do you really want to delete the selected task?"
: "Наистина ли желаете да изтриете селектираната задача?"

, "Task"
: "Задачa"

, "to do list"
: "списък със задачи"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
